@@ -12,6 +12,8 @@ function(data, grouping)
    nlev <- nlevels(grouping)
    lev <- levels(grouping)
    dfs <- tapply(grouping, grouping, length) - 1
+   if (any(dfs < p)) 
+      stop("there are one or more levels with less observations than variables!")
    mats <- aux <- list()
    for(i in 1:nlev) {
       mats[[i]] <- cov(data[grouping == lev[i], ])
@@ -21,8 +23,7 @@ function(data, grouping)
    pooled <- Reduce("+", aux) / sum(dfs)
    logdet <- log(unlist(lapply(mats, det)))
    minus2logM <- sum(dfs) * log(det(pooled)) - sum(logdet * dfs)
-   sum1 <- sum(1 / (dfs - 1)) 
-   sum2 <- sum(1 / ((dfs - 1)^2)) 
+   sum1 <- sum(1 / dfs) 
    Co <- (((2 * p^2) + (3 * p) - 1) / (6 * (p + 1) *
      (nlev - 1))) * (sum1 - (1 / sum(dfs)))
    X2 <- minus2logM * (1 - Co)
